==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/aa-ER/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'crwdns1811:0crwdne1811:0',
    'about_locations'           => 'crwdns1812:0crwdne1812:0',
    'assets_rtd'                => 'crwdns1610:0crwdne1610:0', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'crwdns1437:0crwdne1437:0',
    'id'                        => 'crwdns640:0crwdne640:0',
    'city'                      => 'crwdns641:0crwdne641:0',
    'state'                     => 'crwdns642:0crwdne642:0',
    'country'                   => 'crwdns643:0crwdne643:0',
    'create'                    => 'crwdns644:0crwdne644:0',
    'update'                    => 'crwdns645:0crwdne645:0',
    'print_assigned'            => 'crwdns6062:0crwdne6062:0',
    'print_all_assigned'        => 'crwdns6064:0crwdne6064:0',
    'name'                      => 'crwdns646:0crwdne646:0',
    'address'                   => 'crwdns647:0crwdne647:0',
    'address2'                   => 'crwdns11880:0crwdne11880:0',
    'zip'                       => 'crwdns648:0crwdne648:0',
    'locations'                 => 'crwdns649:0crwdne649:0',
    'parent'                    => 'crwdns1388:0crwdne1388:0',
    'currency'                  => 'crwdns1389:0crwdne1389:0',
    'ldap_ou'                   => 'crwdns1839:0crwdne1839:0',
    'user_name'                 => 'crwdns6665:0crwdne6665:0',
    'department'                => 'crwdns6667:0crwdne6667:0',
    'location'                  => 'crwdns6669:0crwdne6669:0',
    'asset_tag'                 => 'crwdns6671:0crwdne6671:0',
    'asset_name'                => 'crwdns6673:0crwdne6673:0',
    'asset_category'            => 'crwdns6675:0crwdne6675:0',
    'asset_manufacturer'        => 'crwdns6677:0crwdne6677:0',
    'asset_model'               => 'crwdns6679:0crwdne6679:0',
    'asset_serial'              => 'crwdns6681:0crwdne6681:0',
    'asset_location'            => 'crwdns6683:0crwdne6683:0',
    'asset_checked_out'         => 'crwdns6685:0crwdne6685:0',
    'asset_expected_checkin'    => 'crwdns6687:0crwdne6687:0',
    'date'                      => 'crwdns6689:0crwdne6689:0',
    'phone'                     => 'crwdns12048:0crwdne12048:0',
    'signed_by_asset_auditor'   => 'crwdns6691:0crwdne6691:0',
    'signed_by_finance_auditor' => 'crwdns6693:0crwdne6693:0',
    'signed_by_location_manager' => 'crwdns6695:0crwdne6695:0',
    'signed_by'                 => 'crwdns6697:0crwdne6697:0',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/aa-ER/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'crwdns1811:0crwdne1811:0',
    'about_locations'           => 'crwdns1812:0crwdne1812:0',
    'assets_rtd'                => 'crwdns1610:0crwdne1610:0', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'crwdns1437:0crwdne1437:0',
    'id'                        => 'crwdns640:0crwdne640:0',
    'city'                      => 'crwdns641:0crwdne641:0',
    'state'                     => 'crwdns642:0crwdne642:0',
    'country'                   => 'crwdns643:0crwdne643:0',
    'create'                    => 'crwdns644:0crwdne644:0',
    'update'                    => 'crwdns645:0crwdne645:0',
    'print_assigned'            => 'crwdns6062:0crwdne6062:0',
    'print_inventory'           => 'crwdns13792:0crwdne13792:0',
    'print_all_assigned'        => 'crwdns13794:0crwdne13794:0',
    'name'                      => 'crwdns646:0crwdne646:0',
    'address'                   => 'crwdns647:0crwdne647:0',
    'address2'                   => 'crwdns11880:0crwdne11880:0',
    'zip'                       => 'crwdns648:0crwdne648:0',
    'locations'                 => 'crwdns649:0crwdne649:0',
    'parent'                    => 'crwdns1388:0crwdne1388:0',
    'currency'                  => 'crwdns1389:0crwdne1389:0',
    'ldap_ou'                   => 'crwdns1839:0crwdne1839:0',
    'user_name'                 => 'crwdns6665:0crwdne6665:0',
    'department'                => 'crwdns6667:0crwdne6667:0',
    'location'                  => 'crwdns6669:0crwdne6669:0',
    'asset_tag'                 => 'crwdns6671:0crwdne6671:0',
    'asset_name'                => 'crwdns6673:0crwdne6673:0',
    'asset_category'            => 'crwdns6675:0crwdne6675:0',
    'asset_manufacturer'        => 'crwdns6677:0crwdne6677:0',
    'asset_model'               => 'crwdns6679:0crwdne6679:0',
    'asset_serial'              => 'crwdns6681:0crwdne6681:0',
    'asset_location'            => 'crwdns6683:0crwdne6683:0',
    'asset_checked_out'         => 'crwdns6685:0crwdne6685:0',
    'asset_expected_checkin'    => 'crwdns6687:0crwdne6687:0',
    'date'                      => 'crwdns6689:0crwdne6689:0',
    'phone'                     => 'crwdns12048:0crwdne12048:0',
    'signed_by_asset_auditor'   => 'crwdns6691:0crwdne6691:0',
    'signed_by_finance_auditor' => 'crwdns6693:0crwdne6693:0',
    'signed_by_location_manager' => 'crwdns6695:0crwdne6695:0',
    'signed_by'                 => 'crwdns6697:0crwdne6697:0',
    'clone'  					=> 'crwdns13240:0crwdne13240:0',
];
